@@ -60,15 +60,17 @@ mkdir tmp
 perl nobgd.pl ../../src/ tmp/
 
 # Add the external docs.
-cp license.txt tmp/
+echo "Title: License" | cat - ../../COPYING > tmp/license.txt
 sed -e "s/@VERSION@/$VERSION/g" preamble.txt > tmp/preamble.txt
 # ^^^ hack to get the version number in the docs.
 
 # Run naturaldocs to create the manual.
 $(nd) --rebuild --rebuild-output --documented-only \
     -i tmp/ \
+    -img images/ \
     -o html html  \
-    --project project/
+    --project project/ \
+    -s Default libgd
 
 # And cleanup the temp files.
 rm -rf Data tmp
